==> alchemyml-0.1.18-py3-none-any.whl: alchemyml/_dict_urlData.py <==
dict_urlData = {'get_api_token': '/token/',
                'preprocessed': '/experiments/preprocessed/',
                'predictions': '/experiments/predictions/',
                'historical_predictions': '/experiments/historical-predictions/',
                'historical_data_agg': '/experiments/historical-data-aggregations/',
                'list_preprocessed_dataframes': '/manual-ops/list-preprocessed-dataframes/',
                'download_dataframe': '/manual-ops/download-dataframe/',
                'prepare_dataframe': '/manual-ops/prepare-dataframe/',
                'encode_dataframe': '/manual-ops/encode-dataframe/',
                'drop_highly_correlated_components': '/manual-ops/drop-highly-correlated-components/',
                'impute_inconsistencies': '/manual-ops/impute-inconsistencies/',
                'drop_invalid_columns': '/manual-ops/drop-invalid-columns/',
                'target_column_analysis': '/manual-ops/target-column-analysis/',
                'balancing_dataframe': '/manual-ops/balance-dataframe/',
                'initial_exp_info': '/manual-ops/initial-exp-info/',
                'impute_missing_values': '/manual-ops/impute-missing-values/',
                'merge_cols_into_dt_index': '/manual-ops/merge-cols-into-dt-index/',
                'detect_experiment_type': '/manual-ops/detect-experiment-type/',
                'build_model': '/manual-ops/build-model/',
                'detect_outliers': '/manual-ops/detect-outliers/',
                'download_properties_df': '/manual-ops/download-properties/',
                'operational_info': '/manual-ops/operational-info/',
                'impute_outliers': '/manual-ops/impute-outliers/',
                'dataset.upload': '/datasets/upload/',
                'dataset.view': '/datasets/list/',
                'dataset.update': '/datasets/update/',
                'dataset.delete': '/datasets/delete/',
                'dataset.statistical_descriptors': '/datasets/statistical-descriptors/',
                'experiment.create': '/experiments/create/',
                'experiment.view': '/experiments/list/',
                'experiment.update': '/experiments/update/',
                'experiment.delete': '/experiments/delete/',
                'experiment.statistical_descriptors': '/experiments/statistical-descriptors/',
                'experiment.results': '/experiments/results/',
                'experiment.add_to_project': '/experiments/add-experiment-to-project/',
                'experiment.extract_from_project': '/experiments/extract-experiment-from-project/',
                'experiment.send': '/experiments/send-experiment/',
                'project.create': '/projects/create/',
                'project.view': '/projects/list/',
                'project.update': '/projects/update/',
                'project.delete': '/projects/delete/'}

==> alchemyml-0.1.34-py3-none-any.whl: alchemyml/_dict_urlData.py <==
dict_urlData = {'get_api_token': '/token/',

                'dataset.upload': '/datasets/upload/',
                'dataset.get': '/datasets/list/',
                'dataset.update': '/datasets/update/',
                'dataset.delete': '/datasets/delete/',
                'dataset.statistical_descriptors': '/datasets/statistical-descriptors/',
                'dataset.download': '/datasets/download/',
                'dataset.send': '/datasets/send-dataset/',

                'experiment.create': '/experiments/create/',
                'experiment.get': '/experiments/list/',
                'experiment.update': '/experiments/update/',
                'experiment.delete': '/experiments/delete/',
                'experiment.statistical_descriptors': '/experiments/statistical-descriptors/',
                'experiment.results': '/experiments/results/',
                'experiment.add_to_project': '/experiments/add-experiment-to-project/',
                'experiment.extract_from_project': '/experiments/extract-experiment-from-project/',
                'experiment.send': '/experiments/send-experiment/',

                'project.create': '/projects/create/',
                'project.get': '/projects/list/',
                'project.update': '/projects/update/',
                'project.delete': '/projects/delete/', 

                'list_preprocessed_dataframes': '/manual-ops/list-preprocessed-dataframes/',
                'download_dataframe': '/manual-ops/download-dataframe/',
                'prepare_dataframe': '/manual-ops/prepare-dataframe/',
                'encode_dataframe': '/manual-ops/encode-dataframe/',
                'drop_highly_correlated_components': '/manual-ops/drop-highly-correlated-components/',
                'impute_inconsistencies': '/manual-ops/impute-inconsistencies/',
                'drop_invalid_columns': '/manual-ops/drop-invalid-columns/',
                'target_column_analysis': '/manual-ops/target-column-analysis/',
                'balancing_dataframe': '/manual-ops/balance-dataframe/',
                'initial_exp_info': '/manual-ops/initial-exp-info/',
                'impute_missing_values': '/manual-ops/impute-missing-values/',
                'merge_cols_into_dt_index': '/manual-ops/merge-cols-into-dt-index/',
                'detect_experiment_type': '/manual-ops/detect-experiment-type/',
                'build_model': '/manual-ops/build-model/',
                'detect_outliers': '/manual-ops/detect-outliers/',
                'operational_info': '/manual-ops/operational-info/',
                'impute_outliers': '/manual-ops/impute-outliers/', 
                
                'preprocessed': '/experiments/preprocessed/',
                'predictions': '/experiments/predictions/',
                'historical_predictions': '/experiments/historical-predictions/',
                'historical_data_agg': '/experiments/historical-data-aggregations/'}
